@@ -14,7 +14,10 @@ class CreateCases:
         self.region = None
         self.emission = None
         self.technology = None
+        self.capacity_technology = None
         self.fuel = None
+        self.specified_fuel = None
+        self.accumulated_fuel = None
         self.timeslice = None
         self.mode_of_operation = None
         self.storage = None
@@ -113,6 +116,14 @@ class CreateCases:
         """
         self.technology = technology
 
+    def set_capacity_technology(self, capacity_technology):
+        """ Sets the cases capacity_technology type
+
+        Args:
+            capacity_technology (list): List of technologies
+        """
+        self.capacity_technology = capacity_technology
+
     def set_fuel(self, fuel):
         """ Sets the case's fuel types
 
@@ -121,6 +132,22 @@ class CreateCases:
         """
         self.fuel = fuel
 
+    def set_specified_fuel(self, specified_fuel):
+        """ Sets the case's specified fuel types
+
+        Args:
+            specified_fuel (list): list of specified fuels
+        """
+        self.specified_fuel = specified_fuel
+
+    def set_accumulated_fuel(self, accumulated_fuel):
+        """ Sets the case's accumulated fuel types
+
+        Args:
+            specified_fuel (list): list of specified fuels
+        """
+        self.accumulated_fuel = accumulated_fuel
+
     def set_timeslice(self, timeslice):
         """ Set of timeslices
 
@@ -388,33 +415,76 @@ class CreateCases:
         else:
             self.DepreciationMethod = override
 
-    def set_specified_annual_demand(self, parameters):
-        """[summary]
+    def set_specified_annual_demand(self, specified_forecast):
+        """ Sets the annual demand for fuels per region over the forecast period (Must be accurate)
 
         Args:
-            parameters ([type]): [description]
+            forecast (float, array): The forecast array of size (len(region),len(fuel),len(year))
         """
+        self.SpecifiedAnnualDemand = specified_forecast
 
-    def set_specified_demand_profile(self, parameters):
-        """[summary]
+    def set_specified_demand_profile(self, specified_annual_demand, region,
+                                     fuel, year, timeslice, profile, override):
+        """ Sets the specified annual demand profiles using the specified annual demand.
 
         Args:
-            parameters ([type]): [description]
+            specified_annual_demand (float, array): Specified annual demand profiles
+            region (list): List of regions
+            fuel (list): List of fuels
+            year (list): List of years
+            timeslice (list): List of timeslices
+            profile (Dict): Dictionary of fuel allocations to timeslices
+            override (float, array): Manual override for the specified annual demand profiles.
         """
+        # Initialises the linear array
+        demand_profile = np.zeros(
+            (len(region), len(fuel), len(timeslice), len(year)))
+        if override == None:
+            # Calculates the demand profile
+            for place in region:
+                for fuel_type in fuel:
+                    for time in timeslice:
+                        for year_num in year:
+                            region_index = region.index(place)
+                            fuel_index = fuel.index(fuel_type)
+                            timeslice_index = timeslice.index(time)
+                            year_index = year.index(year_num)
+                            demand_profile[region_index, fuel_index,
+                                           timeslice_index,
+                                           year_index] = profile[time]
 
-    def set_accumulated_annual_demand(self, parameters):
-        """[summary]
+            self.SpecifiedDemandProfile = demand_profile
+        else:
+            self.SpecifiedDemandProfile = override
+
+    def set_accumulated_annual_demand(self, accumulated_forecast):
+        """ Sets the accumulated annual demand for fuels per region over the forecast period.
+            This function relies on a similar forecasting methodology as set_specific_demand.
+            Fuels set in this function cannot be defined in set_specific_demand.
 
         Args:
-            parameters ([type]): [description]
+            accumulated_forecast (float, array): The forecast array of size (len(region),len(fuel),len(year))
         """
+        self.AccumulatedAnnualDemand = accumulated_forecast
 
-    def set_capacity_to_activity_unit(self, parameters):
-        """[summary]
+    def set_capacity_to_activity_unit(self, region, technology,
+                                      capacity_dictionaries, override):
+        """ Sets the capacity to activity parameter
 
         Args:
-            parameters ([type]): [description]
+            region (list): List of regions
+            technology (list): List of technologies
+            capacity_dictionaries (list): List of dictionaries to assign value
+            override (float, array) = 2D Array to assign override values
         """
+        if override == None:
+            cap_to_act = np.zeros((len(region), len(technology)))
+            for i in range(0, len(capacity_dictionaries), 1):
+                for j in range(0, len(technology), 1):
+                    cap_to_act[i, j] = capacity_dictionaries[i][technology[j]]
+            self.CapacityToActivityUnit = cap_to_act
+        else:
+            self.CapacityToActivityUnit = override
 
     def set_capacity_factor(self, parameters):
         """[summary]
